Documentation
¶
Overview ¶
Package org_apache_beam_runner_api_v1 is a generated protocol buffer package.
It is generated from these files:
beam_artifact_api.proto
It has these top-level messages:
ArtifactMetadata Manifest ProxyManifest GetManifestRequest GetManifestResponse GetArtifactRequest ArtifactChunk PutArtifactRequest PutArtifactResponse CommitManifestRequest CommitManifestResponse
Index ¶
- func RegisterArtifactRetrievalServiceServer(s *grpc.Server, srv ArtifactRetrievalServiceServer)
- func RegisterArtifactStagingServiceServer(s *grpc.Server, srv ArtifactStagingServiceServer)
- type ArtifactChunk
- type ArtifactMetadata
- func (*ArtifactMetadata) Descriptor() ([]byte, []int)
- func (m *ArtifactMetadata) GetMd5() string
- func (m *ArtifactMetadata) GetName() string
- func (m *ArtifactMetadata) GetPermissions() uint32
- func (*ArtifactMetadata) ProtoMessage()
- func (m *ArtifactMetadata) Reset()
- func (m *ArtifactMetadata) String() string
- type ArtifactRetrievalServiceClient
- type ArtifactRetrievalServiceServer
- type ArtifactRetrievalService_GetArtifactClient
- type ArtifactRetrievalService_GetArtifactServer
- type ArtifactStagingServiceClient
- type ArtifactStagingServiceServer
- type ArtifactStagingService_PutArtifactClient
- type ArtifactStagingService_PutArtifactServer
- type CommitManifestRequest
- type CommitManifestResponse
- type GetArtifactRequest
- type GetManifestRequest
- type GetManifestResponse
- type Manifest
- type ProxyManifest
- type ProxyManifest_Location
- type PutArtifactRequest
- func (*PutArtifactRequest) Descriptor() ([]byte, []int)
- func (m *PutArtifactRequest) GetContent() isPutArtifactRequest_Content
- func (m *PutArtifactRequest) GetData() *ArtifactChunk
- func (m *PutArtifactRequest) GetMetadata() *ArtifactMetadata
- func (*PutArtifactRequest) ProtoMessage()
- func (m *PutArtifactRequest) Reset()
- func (m *PutArtifactRequest) String() string
- func (*PutArtifactRequest) XXX_OneofFuncs() (func(msg proto.Message, b *proto.Buffer) error, ...)
- type PutArtifactRequest_Data
- type PutArtifactRequest_Metadata
- type PutArtifactResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterArtifactRetrievalServiceServer ¶
func RegisterArtifactRetrievalServiceServer(s *grpc.Server, srv ArtifactRetrievalServiceServer)
func RegisterArtifactStagingServiceServer ¶
func RegisterArtifactStagingServiceServer(s *grpc.Server, srv ArtifactStagingServiceServer)
Types ¶
type ArtifactChunk ¶
type ArtifactChunk struct {
Data []byte `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
}
Part of an artifact.
func (*ArtifactChunk) Descriptor ¶
func (*ArtifactChunk) Descriptor() ([]byte, []int)
func (*ArtifactChunk) GetData ¶
func (m *ArtifactChunk) GetData() []byte
func (*ArtifactChunk) ProtoMessage ¶
func (*ArtifactChunk) ProtoMessage()
func (*ArtifactChunk) Reset ¶
func (m *ArtifactChunk) Reset()
func (*ArtifactChunk) String ¶
func (m *ArtifactChunk) String() string
type ArtifactMetadata ¶
type ArtifactMetadata struct {
// (Required) The name of the artifact.
Name string `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
// (Optional) The Unix-like permissions of the artifact
Permissions uint32 `protobuf:"varint,2,opt,name=permissions" json:"permissions,omitempty"`
// (Optional) The base64-encoded md5 checksum of the artifact. Used, among other things, by
// harness boot code to validate the integrity of the artifact.
Md5 string `protobuf:"bytes,3,opt,name=md5" json:"md5,omitempty"`
}
An artifact identifier and associated metadata.
func (*ArtifactMetadata) Descriptor ¶
func (*ArtifactMetadata) Descriptor() ([]byte, []int)
func (*ArtifactMetadata) GetMd5 ¶
func (m *ArtifactMetadata) GetMd5() string
func (*ArtifactMetadata) GetName ¶
func (m *ArtifactMetadata) GetName() string
func (*ArtifactMetadata) GetPermissions ¶
func (m *ArtifactMetadata) GetPermissions() uint32
func (*ArtifactMetadata) ProtoMessage ¶
func (*ArtifactMetadata) ProtoMessage()
func (*ArtifactMetadata) Reset ¶
func (m *ArtifactMetadata) Reset()
func (*ArtifactMetadata) String ¶
func (m *ArtifactMetadata) String() string
type ArtifactRetrievalServiceClient ¶
type ArtifactRetrievalServiceClient interface {
// Get the manifest for the job
GetManifest(ctx context.Context, in *GetManifestRequest, opts ...grpc.CallOption) (*GetManifestResponse, error)
// Get an artifact staged for the job. The requested artifact must be within the manifest
GetArtifact(ctx context.Context, in *GetArtifactRequest, opts ...grpc.CallOption) (ArtifactRetrievalService_GetArtifactClient, error)
}
func NewArtifactRetrievalServiceClient ¶
func NewArtifactRetrievalServiceClient(cc *grpc.ClientConn) ArtifactRetrievalServiceClient
type ArtifactRetrievalServiceServer ¶
type ArtifactRetrievalServiceServer interface {
// Get the manifest for the job
GetManifest(context.Context, *GetManifestRequest) (*GetManifestResponse, error)
// Get an artifact staged for the job. The requested artifact must be within the manifest
GetArtifact(*GetArtifactRequest, ArtifactRetrievalService_GetArtifactServer) error
}
type ArtifactRetrievalService_GetArtifactClient ¶
type ArtifactRetrievalService_GetArtifactClient interface {
Recv() (*ArtifactChunk, error)
grpc.ClientStream
}
type ArtifactRetrievalService_GetArtifactServer ¶
type ArtifactRetrievalService_GetArtifactServer interface {
Send(*ArtifactChunk) error
grpc.ServerStream
}
type ArtifactStagingServiceClient ¶
type ArtifactStagingServiceClient interface {
// Stage an artifact to be available during job execution. The first request must contain the
// name of the artifact. All future requests must contain sequential chunks of the content of
// the artifact.
PutArtifact(ctx context.Context, opts ...grpc.CallOption) (ArtifactStagingService_PutArtifactClient, error)
// Commit the manifest for a Job. All artifacts must have been successfully uploaded
// before this call is made.
//
// Throws error INVALID_ARGUMENT if not all of the members of the manifest are present
CommitManifest(ctx context.Context, in *CommitManifestRequest, opts ...grpc.CallOption) (*CommitManifestResponse, error)
}
func NewArtifactStagingServiceClient ¶
func NewArtifactStagingServiceClient(cc *grpc.ClientConn) ArtifactStagingServiceClient
type ArtifactStagingServiceServer ¶
type ArtifactStagingServiceServer interface {
// Stage an artifact to be available during job execution. The first request must contain the
// name of the artifact. All future requests must contain sequential chunks of the content of
// the artifact.
PutArtifact(ArtifactStagingService_PutArtifactServer) error
// Commit the manifest for a Job. All artifacts must have been successfully uploaded
// before this call is made.
//
// Throws error INVALID_ARGUMENT if not all of the members of the manifest are present
CommitManifest(context.Context, *CommitManifestRequest) (*CommitManifestResponse, error)
}
type ArtifactStagingService_PutArtifactClient ¶
type ArtifactStagingService_PutArtifactClient interface {
Send(*PutArtifactRequest) error
CloseAndRecv() (*PutArtifactResponse, error)
grpc.ClientStream
}
type ArtifactStagingService_PutArtifactServer ¶
type ArtifactStagingService_PutArtifactServer interface {
SendAndClose(*PutArtifactResponse) error
Recv() (*PutArtifactRequest, error)
grpc.ServerStream
}
type CommitManifestRequest ¶
type CommitManifestRequest struct {
// (Required) The manifest to commit.
Manifest *Manifest `protobuf:"bytes,1,opt,name=manifest" json:"manifest,omitempty"`
}
A request to commit the manifest for a Job. All artifacts must have been successfully uploaded before this call is made.
func (*CommitManifestRequest) Descriptor ¶
func (*CommitManifestRequest) Descriptor() ([]byte, []int)
func (*CommitManifestRequest) GetManifest ¶
func (m *CommitManifestRequest) GetManifest() *Manifest
func (*CommitManifestRequest) ProtoMessage ¶
func (*CommitManifestRequest) ProtoMessage()
func (*CommitManifestRequest) Reset ¶
func (m *CommitManifestRequest) Reset()
func (*CommitManifestRequest) String ¶
func (m *CommitManifestRequest) String() string
type CommitManifestResponse ¶
type CommitManifestResponse struct {
// (Required) An opaque token representing the entirety of the staged artifacts.
StagingToken string `protobuf:"bytes,1,opt,name=staging_token,json=stagingToken" json:"staging_token,omitempty"`
}
The result of committing a manifest.
func (*CommitManifestResponse) Descriptor ¶
func (*CommitManifestResponse) Descriptor() ([]byte, []int)
func (*CommitManifestResponse) GetStagingToken ¶
func (m *CommitManifestResponse) GetStagingToken() string
func (*CommitManifestResponse) ProtoMessage ¶
func (*CommitManifestResponse) ProtoMessage()
func (*CommitManifestResponse) Reset ¶
func (m *CommitManifestResponse) Reset()
func (*CommitManifestResponse) String ¶
func (m *CommitManifestResponse) String() string
type GetArtifactRequest ¶
type GetArtifactRequest struct {
// (Required) The name of the artifact to retrieve.
Name string `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
}
A request to get an artifact. The artifact must be present in the manifest for the job.
func (*GetArtifactRequest) Descriptor ¶
func (*GetArtifactRequest) Descriptor() ([]byte, []int)
func (*GetArtifactRequest) GetName ¶
func (m *GetArtifactRequest) GetName() string
func (*GetArtifactRequest) ProtoMessage ¶
func (*GetArtifactRequest) ProtoMessage()
func (*GetArtifactRequest) Reset ¶
func (m *GetArtifactRequest) Reset()
func (*GetArtifactRequest) String ¶
func (m *GetArtifactRequest) String() string
type GetManifestRequest ¶
type GetManifestRequest struct {
}
A request to get the manifest of a Job.
func (*GetManifestRequest) Descriptor ¶
func (*GetManifestRequest) Descriptor() ([]byte, []int)
func (*GetManifestRequest) ProtoMessage ¶
func (*GetManifestRequest) ProtoMessage()
func (*GetManifestRequest) Reset ¶
func (m *GetManifestRequest) Reset()
func (*GetManifestRequest) String ¶
func (m *GetManifestRequest) String() string
type GetManifestResponse ¶
type GetManifestResponse struct {
Manifest *Manifest `protobuf:"bytes,1,opt,name=manifest" json:"manifest,omitempty"`
}
A response containing a job manifest.
func (*GetManifestResponse) Descriptor ¶
func (*GetManifestResponse) Descriptor() ([]byte, []int)
func (*GetManifestResponse) GetManifest ¶
func (m *GetManifestResponse) GetManifest() *Manifest
func (*GetManifestResponse) ProtoMessage ¶
func (*GetManifestResponse) ProtoMessage()
func (*GetManifestResponse) Reset ¶
func (m *GetManifestResponse) Reset()
func (*GetManifestResponse) String ¶
func (m *GetManifestResponse) String() string
type Manifest ¶
type Manifest struct {
Artifact []*ArtifactMetadata `protobuf:"bytes,1,rep,name=artifact" json:"artifact,omitempty"`
}
A collection of artifacts.
func (*Manifest) Descriptor ¶
func (*Manifest) GetArtifact ¶
func (m *Manifest) GetArtifact() []*ArtifactMetadata
func (*Manifest) ProtoMessage ¶
func (*Manifest) ProtoMessage()
type ProxyManifest ¶
type ProxyManifest struct {
Manifest *Manifest `protobuf:"bytes,1,opt,name=manifest" json:"manifest,omitempty"`
Location []*ProxyManifest_Location `protobuf:"bytes,2,rep,name=location" json:"location,omitempty"`
}
A manifest with location information.
func (*ProxyManifest) Descriptor ¶
func (*ProxyManifest) Descriptor() ([]byte, []int)
func (*ProxyManifest) GetLocation ¶
func (m *ProxyManifest) GetLocation() []*ProxyManifest_Location
func (*ProxyManifest) GetManifest ¶
func (m *ProxyManifest) GetManifest() *Manifest
func (*ProxyManifest) ProtoMessage ¶
func (*ProxyManifest) ProtoMessage()
func (*ProxyManifest) Reset ¶
func (m *ProxyManifest) Reset()
func (*ProxyManifest) String ¶
func (m *ProxyManifest) String() string
type ProxyManifest_Location ¶
type ProxyManifest_Location struct {
Name string `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
Uri string `protobuf:"bytes,2,opt,name=uri" json:"uri,omitempty"`
}
func (*ProxyManifest_Location) Descriptor ¶
func (*ProxyManifest_Location) Descriptor() ([]byte, []int)
func (*ProxyManifest_Location) GetName ¶
func (m *ProxyManifest_Location) GetName() string
func (*ProxyManifest_Location) GetUri ¶
func (m *ProxyManifest_Location) GetUri() string
func (*ProxyManifest_Location) ProtoMessage ¶
func (*ProxyManifest_Location) ProtoMessage()
func (*ProxyManifest_Location) Reset ¶
func (m *ProxyManifest_Location) Reset()
func (*ProxyManifest_Location) String ¶
func (m *ProxyManifest_Location) String() string
type PutArtifactRequest ¶
type PutArtifactRequest struct {
// (Required)
//
// Types that are valid to be assigned to Content:
// *PutArtifactRequest_Metadata
// *PutArtifactRequest_Data
Content isPutArtifactRequest_Content `protobuf_oneof:"content"`
}
A request to stage an artifact.
func (*PutArtifactRequest) Descriptor ¶
func (*PutArtifactRequest) Descriptor() ([]byte, []int)
func (*PutArtifactRequest) GetContent ¶
func (m *PutArtifactRequest) GetContent() isPutArtifactRequest_Content
func (*PutArtifactRequest) GetData ¶
func (m *PutArtifactRequest) GetData() *ArtifactChunk
func (*PutArtifactRequest) GetMetadata ¶
func (m *PutArtifactRequest) GetMetadata() *ArtifactMetadata
func (*PutArtifactRequest) ProtoMessage ¶
func (*PutArtifactRequest) ProtoMessage()
func (*PutArtifactRequest) Reset ¶
func (m *PutArtifactRequest) Reset()
func (*PutArtifactRequest) String ¶
func (m *PutArtifactRequest) String() string
func (*PutArtifactRequest) XXX_OneofFuncs ¶
func (*PutArtifactRequest) XXX_OneofFuncs() (func(msg proto.Message, b *proto.Buffer) error, func(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error), func(msg proto.Message) (n int), []interface{})
XXX_OneofFuncs is for the internal use of the proto package.
type PutArtifactRequest_Data ¶
type PutArtifactRequest_Data struct {
Data *ArtifactChunk `protobuf:"bytes,2,opt,name=data,oneof"`
}
type PutArtifactRequest_Metadata ¶
type PutArtifactRequest_Metadata struct {
Metadata *ArtifactMetadata `protobuf:"bytes,1,opt,name=metadata,oneof"`
}
type PutArtifactResponse ¶
type PutArtifactResponse struct {
}
func (*PutArtifactResponse) Descriptor ¶
func (*PutArtifactResponse) Descriptor() ([]byte, []int)
func (*PutArtifactResponse) ProtoMessage ¶
func (*PutArtifactResponse) ProtoMessage()
func (*PutArtifactResponse) Reset ¶
func (m *PutArtifactResponse) Reset()
func (*PutArtifactResponse) String ¶
func (m *PutArtifactResponse) String() string